@@ -1,5 +1,4 @@
 import time
-import urllib
 import logging
 
 logger = logging.getLogger("pyuploadcare")
@@ -7,6 +6,7 @@ logger = logging.getLogger("pyuploadcare")
 
 RESIZER_BASE = 'http://services.uploadcare.com/resizer/%(file_id)s/%(cmd_line)s/'
 
+
 class LazyFile(object):
     def __init__(self, id, ucare):
         self.id = id
@@ -47,7 +47,7 @@ class File(object):
         return super(File, self).__getattr__(name)
 
     def keep(self, wait=False):
-        self._info = self.ucare.make_request('POST', self.api_uri(), {'keep': 1})
+        self._info = self.ucare.make_request('POST', self.api_uri, {'keep': 1})
 
         if wait:
             while not self.info['on_s3']:
@@ -55,7 +55,7 @@ class File(object):
                 time.sleep(0.1)
 
     def delete(self):
-        self.ucare.make_request('DELETE', self.api_uri())
+        self.ucare.make_request('DELETE', self.api_uri)
 
     @property
     def info(self):
@@ -65,36 +65,40 @@ class File(object):
         return self._info
 
     def update_info(self):
-        self._info = self.ucare.make_request('GET', self.api_uri())
+        self._info = self.ucare.make_request('GET', self.api_uri)
 
+    @property
     def api_uri(self):
         return '/files/%s/' % self.file_id
 
     def serialize(self):
-        """Returns a string suitable to be stored somethere. It's either an URL (to save a request) or just file-id"""
+        """Returns a string suitable to be stored somewhere.
+        It's either an URL (to save a request) or just file-id"""
 
-        if self._info and self.url():
-            return self.url()
+        if self._info and self.url:
+            return self.url
 
         return self.file_id
 
+    @property
     def url(self):
         if self._cached_url:
             return self._cached_url
 
         return self.info['original_file_url']
 
+    @property
     def filename(self):
-        if not self.url():
+        if not self.url:
             return ''
 
-        return self.url().split('/')[-1]
+        return self.url.split('/')[-1]
 
     def resized(self, width=None, height=None, crop=False):
         dimensions = str(width or '')
 
         if height:
-            dimensions += 'x%i' % height 
+            dimensions += 'x%i' % height
 
         chunks = [dimensions]
 
@@ -107,8 +111,5 @@ class File(object):
 
     def string_resized(self, cmd_line):
         cmd_line = cmd_line.replace('_', '/')
-        
+
         return RESIZER_BASE % {'file_id': self.file_id, 'cmd_line': cmd_line}
-
-
-
